% Calculates number of accidents for head-on and overtaking collisions,
% type I and II groundings. 

clear all
%--------------------------------------------------------------------------
% Parameters
% route 1: Stad tunnel route
% route 2: Stad route - over obstacles
% route 3: Stad route - around obstacles
route = 1;
t = 0.083; % Fraction of leg distance between nav checks
[Bw,Lw,X,o1s,o2s,o1n,o2n,zn,zs] = route_parameters(route);
n_sections = length(Bw); 

% Lateral distribution parameters:
load('Hitra_pos'); %Hitra channel area data Nov2016-Nov2017
[muS,muN,sigmaS,sigmaN] = latdist_filter(pos, ia);
sigmaS=0.05;
sigmaN=0.05;

% Traffic density data
load('Stad_pos') % Stad area traffic data, Oct2016-Oct2017
[A1,AE1,ki1,kae1] = passline_count(pos,ia);
Q = (AE1)/2; % n vessels each way [1/yr]
q = Q/(365*24*3600); %[1/s]

load('Stad_pos_dim') %Data for Stad area March2017 with Vessel parameters
[A,AE,ki,kae] = passline_count(pos,ia); 
[Vstats,Stats,vType] = vesselstats(vType,pos,ki,ia,kae);

%Vessel group parameters
n_groups = length(Stats); % Number of vessel types
f = Stats(:,1)/sum(Stats(:,1)); % Group fraction of traffic
Qi = f*Q; % Amount of vessels in group [1/yr]
qi = f*q; % [1/s]
v_g = zeros(n_groups,n_sections); 
for i = 1:n_sections
    v_g(:,i) = Stats(:,5); %[knts]
end

if route == 1
    v_g(:,4:8) = 8; %Speed restriction in sections 4-8, 8 [knts]
end

v_g = v_g*0.5144;%[m/s]
b_g = Stats(:,2); %Avg beam [m]

sigmaSN = sqrt(sigmaN^2+sigmaS^2); %Standard deviation of both distrib.
sigmaSN = Bw.*sigmaSN; %[m]
muSN = (muN-muS)*Bw; %[m]

%--------------------------------------------------------------------------
%IWRAP method for calculating head-on collisions

Nghoc=zeros(n_groups,n_groups);

for k = 1:n_sections
    for i = 1:n_groups
        for j=1:n_groups 
            Pgoc(i,j) = normcdf(((b_g(i)+b_g(j))/2-muSN(k))/sigmaSN(k))...
                -normcdf((-((b_g(i)+b_g(j))/2+muSN(k)))/sigmaSN(k));
            Nghoc(i,j) = (Pgoc(i,j)*...
                (v_g(i,k)+v_g(j,k))/(v_g(i,k)*v_g(j,k))*qi(i)*qi(j));
        end
    end

    Nghoc = Nghoc*Lw(k); % Acc. candidates per vessel type and section
    Nghoc = Nghoc*(365*24*3600);  %[1/yr]
    tNghoc(k) = sum(sum((Nghoc))); % Number of acc. candidates per section
end

ttNghoc = sum(tNghoc); % Total number of accident candidates

%--------------------------------------------------------------------------
% Overtaking collisions

for k = 1:n_sections
    for i = 1:n_groups
        for j=1:n_groups
            if v_g(i,k)>v_g(j,k)
            Pgoc(i,j)=normcdf(((b_g(i)+b_g(j))/2)/sigmaSN(k))...
                -normcdf((-((b_g(i)+b_g(j))/2))/sigmaSN(k));
            Ngoc(i,j)=(Pgoc(i,j)*...
                (v_g(i,k)-v_g(j,k))/(v_g(i,k)*v_g(j,k))*qi(i)*qi(j));
            else 
                Pgoc(i,j)=0;
                Ngoc(i,j)=0;
            end
        end
    end
    Ngoc = Ngoc*Lw(k); % Acc. candidates per vessel type and section
    Ngoc = Ngoc*(365*24*3600); % [1/yr]
    tNgoc(k) = sum(sum((Ngoc))); % Number of acc. candidates per section
end

ttNgoc = sum(tNgoc); % Total number of accident candidates

%--------------------------------------------------------------------------
% Total number of collision accidents

PcHoc = 0.5*10^-4;
PcOc = 1.1*10^-4;
Nahoc = PcHoc*(ttNghoc);
Naoc = PcOc*(ttNgoc);
Nacol = Naoc+Nahoc;
disp('Collisions per yr =');
disp(Nacol);
%--------------------------------------------------------------------------
% IWRAP type I grounding probabilty (hit obstacles in lane) 

sigmaS = Bw*sigmaS;
sigmaN = Bw*sigmaN;
muS = Bw.*muS;
muN = Bw.*muN;

for i =1:n_sections
    X(i,:) = X(i,:)*Bw(i);
    Pg1s(i) = normcdf((X(i,2)-muS(i))/sigmaS(i))...
        -normcdf((X(i,1)-muS(i))/sigmaS(i)); 
    Ng1s(i) = Q*Pg1s(i);
    Pg1n(i) = normcdf((X(i,2)-muN(i))/sigmaN(i))...
        -normcdf((X(i,1)-muN(i))/sigmaN(i));
    Ng1n(i) = Q*Pg1n(i);
end

tNg1s = sum(Ng1s);
tNg1n = sum(Ng1n);
Ng1 = tNg1n+tNg1s;
%--------------------------------------------------------------------------
%IWRAP type II grounding probability (failure to change course at bend)

ai = t*Lw; % Mean distance between navigational checks

if route == 1 % Correction for "double" sections
    ai(4) = t*Lw(4)+t*Lw(3);
    ai(3) = t*Lw(4)+t*Lw(3);
else
    ai(3)=t*Lw(3)+t*Lw(4);
    ai(4)=t*Lw(3)+t*Lw(4);
end

% Obstacle function - describes obstacle orientation to lane
for i = 1:n_sections
    o2s(i,1) = o2s(i,1)*Bw(i);
    v(i,:) = [(o2s(i,2)-o1s(i,2)),(o2s(i,1)-o1s(i,1))];
    a(i) = v(i,1)/v(i,2);
    b(i) = -a(i)*(o1s(i,1))+o1s(i,2);
end

Ng2s = zeros(n_groups,n_sections);

for i = 1:n_sections
    zs(i,:) = zs(i,:)*Bw(i);
    for j = 1:n_groups
        p1(j,i) = (2*normcdf((zs(i,1)*ai(i)+a(i)^2*sigmaS(i)^2)/...
            (sigmaS(i)*ai(i)))-1); 
        p2(j,i) = (2*normcdf((zs(i,2)*ai(i)+a(i)^2*sigmaS(i)^2)/...
            (sigmaS(i)*ai(i)))-1);
        Ng2s(j,i) = (0.5*exp((a(i)^2*sigmaS(i)^2-2*b(i)*ai(i))/...
            (2*ai(i)^2)))...
        *(p2(j,i)-p1(j,i));
        Ng2s(j,i) = Ng2s(j,i)*Qi(j);
    end
end

tNg2s = sum(Ng2s);
ttNg2s = sum(tNg2s);

for i = 1:n_sections
    o2n(i,1) = o2n(i,1)*Bw(i);
    v(i,:) = [(o2n(i,2)-o1n(i,2)),(o2n(i,1)-o1n(i,1))];
    a(i) = v(i,1)/v(i,2);
    b(i) = -a(i)*(o1n(i,1))+o1n(i,2);
end


for i = 1:n_sections
    zn(i,:) = zn(i,:)*Bw(i);
    for j = 1:n_groups
        p1(j,i) = (2*normcdf((zn(i,1)*ai(i)+a(i)^2*sigmaN(i)^2)/...
            (sigmaN(i)*ai(i)))-1); 
        p2(j,i) = (2*normcdf((zn(i,2)*ai(i)+a(i)^2*sigmaN(i)^2)/...
            (sigmaN(i)*ai(i)))-1);
        Ng2n(j,i) = (0.5*exp((a(i)^2*sigmaN(i)^2-2*b(i)*ai(i))/...
            (2*ai(i)^2)))...
        *(p2(j,i)-p1(j,i));
        Ng2n(j,i) = Ng2n(j,i)*Qi(j); 
    end
end

tNg2n = sum(Ng2n);
ttNg2n = sum(tNg2n);
Ng2 = ttNg2n+ttNg2s;

%--------------------------------------------------------------------------
% Total number of grounding accidents
Pcg = 1.6*10^-4;
Naground = (Ng2+Ng1)*Pcg;
disp('groundings per yr =');
disp(Naground);

% Accident candidate matrix                
Nmat = [tNghoc;tNgoc;Ng1n;Ng1s;tNg2n;tNg2s];
for i = 1:length(Nmat(:,1))
    Nmat(i,n_sections+1) = sum(Nmat(i,:));
end

xlswrite('Results.xls',Nmat);   
