function [muS,muN,sigmaS,sigmaN] = latdist_filter(pos,ia)
% LATDIST_FILTER finds lateral distributions across defined cross-sections 
% and creates distribution histograms per vessel
%
% Inputs:
%   pos: Vessel position matrix
%   ia:  vessel indexes in position matrix
%
% Outputs:
%   muS:    Southbound mean position mu
%   muN:    Northbound mean position mu
%   sigmaS: Southbound standard deviation sigma
%   sigmaN: Northbound standard deviation sigma
%

ID = pos(:,1);  % Vessel ID
long = pos(:,2);% Longitude
lat = pos(:,3); % Latitude
n_v = length(ia); % n vessels
n_m = length(pos); % n messages

% Trondheimsleia, Hitra
% Snekkflua-Eitera
H1 = [8.7247,63.4524];
H2 = [8.7535,63.4246];

% Cross section line function
v = [(H2(2)-H1(2)),(H2(1)-H1(1))];
a = v(1)/v(2);
c = -a*(H1(1))+H1(2);


% Southbound vessels lateral distributions----------------------------------
for i = 1:n_v-1
    for j = ia(i):ia(i+1)-1 
        if ID(j)==ID(j+1)&&lat(j)>a*long(j)+c&&lat(j+1)<=a*long(j+1)+c&&...
                long(j+1)>=H1(1)&&long(j+1)<=H2(1)
            V1(i,:) = [long(j),lat(j)];
            V2(i,:) = [long(j+1),lat(j+1)];
            vV(i,:) = [(V2(i,2)-V1(i,2)),(V2(i,1)-V1(i,1))];
            b(i) = vV(i,1)/vV(i,2);
            d(i) = -b(i)*(V1(i,1))+V1(i,2);
            S(i,:)= [(d(i)-c)/(a-b(i)),(a*d(i)-b(i)*c)/(a-b(i))];
        end
    end
end

% Separate loop for last vessel
for j = ia(n_v):length(pos)-1  
    if ID(j)==ID(j+1)&&lat(j)>a*long(j)+c&&lat(j+1)<=a*long(j+1)+c&&...
            long(j+1)>=H1(1)&&long(j+1)<=H2(1)
        V1(n_v,:) = [long(j),lat(j)];
        V2(n_v,:) = [long(j+1),lat(j+1)];
        vV(n_v,:) = [(V2(n_v,2)-V1(n_v,2)),(V2(n_v,1)-V1(n_v,1))];
        b(n_v) = vV(n_v,1)/vV(n_v,2);
        d(n_v)=-b(n_v)*(V1(n_v,1))+V1(n_v,2);
        S(n_v,:)= [(d(n_v)-c)/(a-b(n_v)),(a*d(n_v)-b(n_v)*c)/(a-b(n_v))];
    end
end


s1 = nonzeros(S(:,1));
s2 = nonzeros(S(:,2));
S1(:,1) = s1;
S1(:,2) = s2;

% Intersect distances from start point of histogram line.
% Start point is lowest longitude
VS = [S1(:,2)-H1(2),S1(:,1)-H1(1)];
VSabs = sqrt((VS(:,1)).^2+(VS(:,2).^2));
v_abs = sqrt((v(1)).^2+(v(2)).^2);
SRatio = VSabs/v_abs;

B = SRatio>1;
b = find(B);
SRatio(b) = [];


% Northbound vessels lateral distributions---------------------------------
for i = 1:n_v-1
    for j = ia(i)+1:ia(i+1)-1                      
        if ID(j)==ID(j+1)&&lat(j-1)<a*long(j-1)+c&&lat(j)>=a*long(j)+c&&...
                long(j)>=H1(1)&&long(j)<=H2(1)
            V1(i,:) = [long(j-1),lat(j-1)];
            V2(i,:) = [long(j),lat(j)];
            vV(i,:) = [(V2(i,2)-V1(i,2)),(V2(i,1)-V1(i,1))];
            b(i) = vV(i,1)/vV(i,2);
            d(i)=-b(i)*(V1(i,1))+V1(i,2);
            N(i,:)= [(d(i)-c)/(a-b(i)),(a*d(i)-b(i)*c)/(a-b(i))];
        end
    end
end

% Separate loop for last vessel
for j = ia(n_v)+1:length(pos)-1
    if ID(j)==ID(j+1)&&lat(j-1)>a*long(j-1)+c && lat(j)<=a*long(j)+c &&...
            long(j)>=H1(1) && long(j)<=H2(1)
        V1(n_v,:) = [long(j-1),lat(j-1)];
        V2(n_v,:) = [long(j),lat(j)];
        vV(n_v,:) = [(V2(n_v,2)-V1(n_v,2)),(V2(n_v,1)-V1(n_v,1))];
        b(n_v) = vV(n_v,1)/vV(n_v,2);
        d(n_v) = -b(n_v)*(V1(n_v,1))+V1(n_v,2);
        N(n_v,:) = [(d(n_v)-c)/(a-b(n_v)),(a*d(n_v)-b(n_v)*c)/(a-b(n_v))];
    end
end

n1 = nonzeros(N(:,1));
n2 = nonzeros(N(:,2));
N1(:,1) = n1;
N1(:,2) = n2;

% Intersect distances from start point of histogram line. Start point is
% lowest longitude

VN = [N1(:,2)-H1(2),N1(:,1)-H1(1)];
VN_abs = sqrt((VN(:,1)).^2+(VN(:,2).^2));
v_abs = sqrt((v(1)).^2+(v(2)).^2);
NRatio = VN_abs/v_abs;

B = NRatio>1;
b = find(B);
NRatio(b) = [];

%--------------------------------------------------------------------------
% Plot histograms of lateral distribution
pdN = fitdist(NRatio,'normal');
pdS = fitdist(SRatio,'normal');
muN = pdN.mu; 
muS = pdS.mu;
sigmaN = pdN.sigma; 
sigmaS = pdS.sigma; 

figure(1)
subplot(1,2,1), histfit(SRatio,40,'normal');
xlim([0 1])
ylabel('n vessels')
xlabel('section of fairway width')
title('Southbound distribution')
subplot(1,2,2),histfit(NRatio,40,'normal')
xlim([0 1])
ylabel('n vessels')
xlabel('section of fairway width')
title('Northbound distribution')

end
